// Sequelize操作示例
const { sequelize, Job, Resume } = require('./sequelize_models');

// 示例：获取所有岗位
async function getAllJobs() {
  try {
    const jobs = await Job.findAll({
      include: [{
        model: Resume,
        attributes: ['id', 'status']
      }]
    });
    console.log('所有岗位:', JSON.stringify(jobs, null, 2));
    return jobs;
  } catch (error) {
    console.error('获取岗位失败:', error);
    throw error;
  }
}

// 示例：触发岗位的AI筛选
async function triggerScreening(jobId) {
  try {
    const job = await Job.findByPk(jobId);
    if (!job) {
      throw new Error('岗位不存在');
    }
    
    // 模拟AI筛选过程
    const pendingResumes = await Resume.findAll({
      where: {
        jobId: jobId,
        status: 'pending'
      }
    });
    
    // 模拟筛选结果
    const updatedResumes = await Promise.all(pendingResumes.map(async resume => {
      // 简单评分逻辑 - 实际应用中可能是复杂的AI模型
      const score = Math.random() * 100;
      const newStatus = score > 70 ? 'passed' : 'rejected';
      
      return await resume.update({
        status: newStatus,
        score: score
      });
    }));
    
    // 更新岗位统计
    const passedCount = updatedResumes.filter(r => r.status === 'passed').length;
    const pendingCount = updatedResumes.filter(r => r.status === 'pending').length;
    
    await job.update({
      pendingResumes: pendingCount,
      passedResumes: job.passedResumes + passedCount
    });
    
    console.log(`岗位 ${job.title} 的AI筛选已完成`);
    return { job, updatedResumes };
  } catch (error) {
    console.error('筛选过程出错:', error);
    throw error;
  }
}

// 测试示例
async function test() {
  try {
    await sequelize.authenticate();
    console.log('数据库连接成功');
    
    // 获取所有岗位
    const jobs = await getAllJobs();
    
    // 对第一个有简历的岗位进行筛选
    const jobWithResumes = jobs.find(j => j.pendingResumes > 0);
    if (jobWithResumes) {
      await triggerScreening(jobWithResumes.id);
    } else {
      console.log('没有待筛选的岗位');
    }
  } catch (error) {
    console.error('操作失败:', error);
  } finally {
    await sequelize.close();
  }
}

// 执行测试
test();    