import sequelize from '../database/config/config.js';  // 修正路径
import Department from '../database/models/department.js';
import Job from '../database/models/job.js';
import Resume from '../database/models/resume.js';
import User from '../database/models/user.js';

async function readData() {
  try {
    // 测试数据库连接
    await sequelize.authenticate();
    console.log('✅ 数据库连接成功');

    // 查询所有岗位
    const jobs = await Job.findAll({ raw: true });
    console.log('\n📋 所有岗位:');
    jobs.forEach(job => {
      console.log(`- ${job.title} (${job.location}) - ${job.status}`);
      console.log(`  待处理简历: ${job.pending_resumes}, 通过简历: ${job.passed_resumes}`);
    });

    // 查询所有简历
    const resumes = await Resume.findAll({ raw: true });
    console.log('\n📄 所有简历:');
    resumes.forEach(resume => {
      console.log(`- ${resume.candidate_name} - ${resume.status} - 分数: ${resume.score}`);
      console.log(`  邮箱: ${resume.email}, 电话: ${resume.phone}`);
    });

    // 查询特定岗位及其简历（示例：ID 为 1 的岗位）
    const jobWithResumes = await Job.findOne({
      where: { id: 1 },
      include: [{ model: Resume, as: 'resumes' }],
      raw: true,
      nest: true
    });

    if (jobWithResumes) {
      console.log(`\n🔍 岗位详情: ${jobWithResumes.title}`);
      console.log(`  描述: ${jobWithResumes.job_description}`);
      console.log(`  要求: ${jobWithResumes.requirements}`);
      console.log(`  该岗位下的简历: ${jobWithResumes.resumes?.length || 0}`);
    }

  } catch (error) {
    console.error('❌ 读取数据失败:', error);
  } finally {
    // 关闭数据库连接
    await sequelize.close();
  }
}

// 执行脚本
readData();